/**
 * @file draw.h
 * @author Tanguy Cavagna (tanguy.cavagna@etu.hesge.ch)
 * @brief Header of the draw file
 * @version 0.1
 * @date 2021-07-12
 *
 * @copyright Copyright (c) 2021
 *
 */

#ifndef _DRAW_H_
#define _DRAW_H_

#include "../gfx/gfx.h"
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>

typedef struct {
    uint32_t row;
    uint32_t column;
} coordinates_t;

/**
 * @brief Create a coordinate
 *
 * @param row_ Row number
 * @param column_ Column number
 * @return coordinates_t
 */
coordinates_t coordinates_create(int row_, int column_);

/**
 * @brief Draw a line using the Bresenham's line algorithm
 *
 * @param ctxt Context to draw on
 * @param p0 Start
 * @param p1 End
 * @param color Stroke color
 */
void gfx_draw_line(struct gfx_context_t *ctxt, coordinates_t p0,
                   coordinates_t p1, uint32_t color);

/**
 * @brief Draw a circle using _______
 *
 * @param ctxt Context to draw on
 * @param c Center
 * @param r Raidus
 * @param color Stroke color
 */
void gfx_draw_circle(struct gfx_context_t *ctxt, coordinates_t c, int r,
                     uint32_t color);

#endif // _DRAW_H_
